@@ -108,8 +108,8 @@ optimizeStrata <-
                                   if (nrow(stcamp[[i]]) == 1) {
                                     solut <- list(c(1), stcamp[[i]][c(1:grep("DOM1", 
                                                                              colnames(stcamp[[i]])))])
-                                    error <- data.frame(erro[[i]])
-                                    strat <- data.frame(solut[[2]])
+                                    error <- data.frame(erro[[i]],stringsAsFactors = TRUE)
+                                    strat <- data.frame(solut[[2]],stringsAsFactors = TRUE)
                                     solut[[2]]$SOLUZ <- sum(bethel(strat, error, 
                                                                    realAllocation = T))
                                     if (solut[[2]]$SOLUZ > solut[[2]]$N) 
@@ -193,8 +193,8 @@ optimizeStrata <-
             if (nrow(stcamp[[i]]) == 1) {
               solut <- list(c(1), stcamp[[i]][c(1:grep("DOM1", 
                                                        colnames(stcamp[[i]])))])
-              error <- data.frame(erro[[i]])
-              strat <- data.frame(solut[[2]])
+              error <- data.frame(erro[[i]],stringsAsFactors = TRUE)
+              strat <- data.frame(solut[[2]],stringsAsFactors = TRUE)
               solut[[2]]$SOLUZ <- sum(bethel(strat, error, 
                                              realAllocation = T))
               if (solut[[2]]$SOLUZ > solut[[2]]$N) 
