@@ -60,7 +60,7 @@ optimizeStrataSpatial <-
             eval(parse(text=paste("framecens$X",i," <- NULL",sep="")))
           }
         }  
-        cens <- buildStrataDFSpatial(dataset=frame,
+        cens <- buildStrataDFSpatial(dataset=framecens,
                                      fitting=fitting,
                                      range=range,
                                      kappa=kappa,
@@ -200,8 +200,8 @@ optimizeStrataSpatial <-
                 solut <- list(c(1), 
                               stcamp[[i]][c(1:grep("DOMAINVALUE", 
                                                    colnames(stcamp[[i]])))])
-                error <- data.frame(erro[[i]])
-                strat <- data.frame(solut[[2]])
+                error <- data.frame(erro[[i]],stringsAsFactors = TRUE)
+                strat <- data.frame(solut[[2]],stringsAsFactors = TRUE)
                 solut[[2]]$SOLUZ <- sum(bethel(strat, error, 
                                                realAllocation = T))
                 if (solut[[2]]$SOLUZ > solut[[2]]$N) 
@@ -300,8 +300,8 @@ optimizeStrataSpatial <-
             if (nrow(stcamp[[i]]) == 1) {
               solut <- list(c(1), stcamp[[i]][c(1:grep("DOMAINVALUE", 
                                                        colnames(stcamp[[i]])))])
-              error <- data.frame(erro[[i]])
-              strat <- data.frame(solut[[2]])
+              error <- data.frame(erro[[i]],stringsAsFactors = TRUE)
+              strat <- data.frame(solut[[2]],stringsAsFactors = TRUE)
               solut[[2]]$SOLUZ <- sum(bethel(strat, error, 
                                              realAllocation = T))
               if (solut[[2]]$SOLUZ > solut[[2]]$N) 
@@ -406,7 +406,7 @@ optimizeStrataSpatial <-
                   row.names = FALSE, col.names = TRUE, quote = FALSE)
       cat("\n...written output to ", direnew,"/outstrata.txt\n")
     }
-    vettsoldf <- as.data.frame(vettsol)
+    vettsoldf <- as.data.frame(vettsol,stringsAsFactors = TRUE)
     colnames(vettsoldf) <- c("ID","LABEL")
     vettsoldf$STRATO <- vettsoldf$LABEL
     framenew <- merge(frame,vettsoldf,by=c("ID"))
